@@ -4,11 +4,6 @@
 Allows describing functions, specifically enumerating arguments which
 may be passed in a combination of registers and stack values.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import gdb
 from capstone import CS_GRP_CALL
 from capstone import CS_GRP_INT
@@ -206,5 +201,12 @@ def format_args(instruction):
     for arg, value in get(instruction):
         code   = arg.type != 'char'
         pretty = pwndbg.chain.format(value, code=code)
+
+        # Enhance args display
+        if arg.name == 'fd' and isinstance(value, int):
+            path = pwndbg.file.readlink('/proc/%d/fd/%d' % (pwndbg.proc.pid, value))
+            if path:
+                pretty += ' (%s)' % path
+
         result.append('%-10s %s' % (N.argument(arg.name) + ':', pretty))
     return result
