@@ -1,6 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-
 import os
 import re
 
@@ -74,7 +71,7 @@ def generateColorFunction(config):
     return function
 
 def strip(x):
-    return re.sub('\x1b\\[\d+m', '', x)
+    return re.sub('\x1b\\[[\d;]+m', '', x)
 
 def terminateWith(x, color):
     return re.sub('\x1b\\[0m', NORMAL + color, x)
