@@ -1,10 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
-import itertools
 import os.path
 import re
 
@@ -15,8 +10,9 @@ from pwndbg.color import theme
 
 try:
     import pygments
-    import pygments.lexers
     import pygments.formatters
+    import pygments.lexers
+
     from pwndbg.color.lexer import PwntoolsLexer
 except ImportError:
     pygments = None
