@@ -3,10 +3,6 @@
 """
 Wrapper for shell commands.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import os
 
@@ -52,6 +48,7 @@ shellcmds = [
     "ps",
     "pstree",
     "pwd",
+    "pwn", # pwntools
     "rm",
     "sed",
     "sh",
