@@ -44,11 +44,13 @@ Memory pages can also be added manually, see vmmap_add, vmmap_clear and vmmap_lo
 parser.formatter_class=argparse.RawDescriptionHelpFormatter
 parser.add_argument('gdbval_or_str', type=pwndbg.commands.sloppy_gdb_parse, nargs='?', default=None,
                     help='Address or module name.')
+parser.add_argument('-w', '--writable', action='store_true', help='Display writable maps only')
+parser.add_argument('-x', '--executable', action='store_true', help='Display executable maps only')
 
 
 @pwndbg.commands.ArgparsedCommand(parser, aliases=['lm', 'address', 'vprot'])
 @pwndbg.commands.OnlyWhenRunning
-def vmmap(gdbval_or_str=None):
+def vmmap(gdbval_or_str=None, writable=False, executable=False):
     pages = pwndbg.vmmap.get()
 
     if gdbval_or_str:
@@ -65,6 +67,8 @@ def vmmap(gdbval_or_str=None):
         print(M.get(page.vaddr, text=str(page) + ' +0x%x' % (int(gdbval_or_str) - page.vaddr)))
     else:
         for page in pages:
+            if (executable and not page.execute) or (writable and not page.write):
+                continue
             print(M.get(page.vaddr, text=str(page)))
 
     if pwndbg.qemu.is_qemu():
@@ -111,14 +115,14 @@ parser.add_argument('filename', nargs='?', type=str, help='ELF filename, by defa
 @pwndbg.commands.ArgparsedCommand(parser)
 def vmmap_load(filename):
     if filename is None:
-        filename = pwndbg.proc.exe
+        filename = pwndbg.file.get_file(pwndbg.proc.exe)
 
     print('Load "%s" ...' % filename)
 
     # TODO: Add an argument to let use to choose loading the page information from sections or segments
 
     # Use section information to recover the segment information.
-    # The entry point of bare metal enviroment is often at the first segment.
+    # The entry point of bare metal environment is often at the first segment.
     # For example, assume the entry point is at 0x8000.
     # In most of case, link will create a segment and starts from 0x0.
     # This cause all values less than 0x8000 be considered as a valid pointer.
