@@ -266,9 +266,3 @@ def near(address, instructions=1, emulate=False, show_prev_insns=True):
 
     return insns
 
-
-def is_call(address=None):
-    """
-    Returns whether a given address contains call instruction.
-    """
-    return capstone.CS_GRP_CALL in one(address).groups
