@@ -4,12 +4,7 @@
 Functions for determining the architecture-dependent path to
 GCC and any flags it should be executed with.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
-import collections
 import glob
 import os
 import platform
