@@ -1,12 +1,10 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-
 from collections import OrderedDict
 
 import gdb
 
 import pwndbg.color.memory as M
 import pwndbg.events
+import pwndbg.glibc
 import pwndbg.typeinfo
 from pwndbg.color import message
 from pwndbg.constants import ptmalloc
@@ -389,11 +387,12 @@ class Heap(pwndbg.heap.heap.BaseHeap):
         fd_offset    = self.chunk_key_offset('fd')
         num_fastbins = 7
         size         = pwndbg.arch.ptrsize * 2
+        safe_lnk = pwndbg.glibc.check_safe_linking()
 
         result = OrderedDict()
         for i in range(num_fastbins):
             size += pwndbg.arch.ptrsize * 2
-            chain = pwndbg.chain.get(int(fastbinsY[i]), offset=fd_offset, limit=heap_chain_limit)
+            chain = pwndbg.chain.get(int(fastbinsY[i]), offset=fd_offset, limit=heap_chain_limit, safe_linking=safe_lnk)
 
             result[size] = chain
 
@@ -411,6 +410,7 @@ class Heap(pwndbg.heap.heap.BaseHeap):
         entries = tcache['entries']
 
         num_tcachebins = entries.type.sizeof // entries.type.target().sizeof
+        safe_lnk = pwndbg.glibc.check_safe_linking()
 
         def tidx2usize(idx):
             """Tcache bin index to chunk size, following tidx2usize macro in glibc malloc.c"""
@@ -420,7 +420,7 @@ class Heap(pwndbg.heap.heap.BaseHeap):
         for i in range(num_tcachebins):
             size = self._request2size(tidx2usize(i))
             count = int(counts[i])
-            chain = pwndbg.chain.get(int(entries[i]), offset=self.tcache_next_offset, limit=heap_chain_limit)
+            chain = pwndbg.chain.get(int(entries[i]), offset=self.tcache_next_offset, limit=heap_chain_limit, safe_linking=safe_lnk)
 
             result[size] = (chain, count)
 
@@ -549,6 +549,8 @@ class Heap(pwndbg.heap.heap.BaseHeap):
 
     def is_initialized(self):
         addr = pwndbg.symbol.address('__libc_malloc_initialized')
+        if addr is None:
+            addr = pwndbg.symbol.address('__malloc_initialized')
         return pwndbg.memory.s32(addr) > 0
 
     def libc_has_debug_syms(self):
