@@ -95,6 +95,7 @@ def write(addr, data):
     if isinstance(data, str):
         data = bytes(data, 'utf8')
 
+    # Throws an exception if can't access memory
     gdb.selected_inferior().write_memory(addr, data)
 
 
@@ -146,8 +147,10 @@ def string(addr, max=4096):
     if peek(addr):
         data = bytearray(read(addr, max, partial=True))
 
-        if b'\x00' in data:
-            return data.split(b'\x00')[0]
+        try:
+            return data[:data.index(b'\x00')]
+        except ValueError:
+            pass
 
     return bytearray()
 
@@ -333,8 +336,12 @@ def find_upper_boundary(addr, max_pages=1024):
             # import sys
             # sys.stdout.write(hex(addr) + '\n')
             addr += pwndbg.memory.PAGE_SIZE
+
+            # Sanity check in case a custom GDB server/stub
+            # incorrectly returns a result from read
+            # (this is most likely redundant, but its ok to keep it?)
             if addr > pwndbg.arch.ptrmask:
-                break
+                return pwndbg.arch.ptrmask
     except gdb.MemoryError:
         pass
     return addr
@@ -352,14 +359,17 @@ def find_lower_boundary(addr, max_pages=1024):
         for i in range(max_pages):
             pwndbg.memory.read(addr, 1)
             addr -= pwndbg.memory.PAGE_SIZE
+
+            # Sanity check (see comment in find_upper_boundary)
             if addr < 0:
-                break
+                return 0
+
     except gdb.MemoryError:
         addr += pwndbg.memory.PAGE_SIZE
     return addr
 
 
-class Page(object):
+class Page:
     """
     Represents the address space and page permissions of at least
     one page of memory.
