@@ -4,7 +4,8 @@ import pwndbg.elf
 import pwndbg.memoize
 
 
-@pwndbg.memoize.reset_on_new_base_address
+@pwndbg.memoize.reset_on_start
+@pwndbg.memoize.reset_on_objfile
 def r2pipe():
     """
     Spawn and return a r2pipe handle for the current process file.
