@@ -38,15 +38,15 @@ def find(address):
             return stack
 
 
-def find_upper_stack_boundary(addr, max_pages=1024):
-    addr = pwndbg.memory.page_align(int(addr))
+def find_upper_stack_boundary(stack_ptr, max_pages=1024):
+    stack_ptr = pwndbg.memory.page_align(int(stack_ptr))
 
     # We can't get the stack size from stack layout and page fault on bare metal mode,
     # so we return current page as a walkaround.
     if not pwndbg.abi.linux:
-        return addr + pwndbg.memory.PAGE_SIZE
+        return stack_ptr + pwndbg.memory.PAGE_SIZE
 
-    return pwndbg.elf.find_elf_magic(addr, max_pages=max_pages, ret_addr_anyway=True)
+    return pwndbg.memory.find_upper_boundary(stack_ptr, max_pages)
 
 
 @pwndbg.events.stop
