@@ -22,7 +22,12 @@ class CollectTestFunctionNames:
 
 
 collector = CollectTestFunctionNames()
-pytest.main(['--collect-only', TESTS_PATH], plugins=[collector])
+rv = pytest.main(['--collect-only', TESTS_PATH], plugins=[collector])
+
+if rv == pytest.ExitCode.INTERRUPTED:
+    print("Failed to collect all tests, perhaps there is a syntax error in one of test files?")
+    sys.exit(1)
+
 
 print('Listing collected tests:')
 for nodeid in collector.collected:
